clear all
capture log close
program drop _all
set more off
snapshot erase _all
set seed 23423

*************************************************************************************
*************************************************************************************
*************************************************************************************
*** MacroHistory Data

use http://macrohistory.net/JST/JSTdatasetR4.dta

*************************************************************************************
*** Keeping variables of interest
keep year country iso ifs gdp cpi stir ltrate bill_rate bond_rate risky_tr safe_tr eq_tr housing_tr bond_tr
replace bill_rate = bill_rate * 100
replace risky_tr = risky_tr * 100
replace safe_tr = safe_tr * 100
replace eq_tr = eq_tr * 100
replace housing_tr = housing_tr * 100
replace bond_tr = bond_tr * 100

*************************************************************************************
*** Growth rates
sort ifs year
bys ifs : g gGDP = (gdp[_n]-gdp[_n-1])/gdp[_n-1]
bys ifs : g infln = (cpi[_n]-cpi[_n-1])/cpi[_n-1]

*************************************************************************************
*** Getting the average of each decade 
recode year (1870/1879 = 1870) (1880/1889 = 1880) (1890/1899 = 1890) (1900/1909 = 1900) (1910/1919 = 1910) (1920/1929= 1920) (1930/1939 = 1930) (1940/1949 = 1940) (1950/1959 = 1950) (1960/1969 = 1960) (1970/1979 = 1970) (1980/1989 = 1980) (1990/1999 = 1990) ( 2000/2009 = 2000) (2010/2016 = 2010), gen (decade)

bysort ifs decade: egen AgGDP = mean(gGDP)
bysort ifs decade: egen Ainfln = mean(infln)
bysort ifs decade: egen Astir = mean(stir)
bysort ifs decade: egen Abill_rate = mean(bill_rate)
bysort ifs decade: egen Arisky_tr = mean(risky_tr)
bysort ifs decade: egen Asafe_tr = mean(safe_tr)
bysort ifs decade: egen Aeq_tr = mean(eq_tr)
bysort ifs decade: egen Ahousing_tr = mean(housing_tr)
bysort ifs decade: egen Abond_tr = mean(bond_tr)

*************************************************************************************
*** Removing duplicate observations
keep decade country ifs AgGDP Ainfln Astir Abill_rate Arisky_tr Asafe_tr Aeq_tr Ahousing_tr Abond_tr
duplicates drop

*** Removing outlier (only one: Germany in 1920s)
drop if AgGDP>1

*** More definitions
gen Ai = AgGDP*100
gen Api = Ainfln*100
gen Agrowth = Ai-Api
gen Aell = Ai-Astir

xtset ifs decade

*************************************************************************************

*** regressions in the paper:
xtreg Arisky_tr Ai Astir, re vce(r) 
outreg2 using table1.tex, tex replace
xtreg Arisky_tr Aell Astir, re vce(r) 
outreg2 using table1.tex, tex append
xtreg Aeq_tr Ai Astir, re vce(r) 
outreg2 using table1.tex, tex append
xtreg Aeq_tr Aell Astir, re vce(r) 
outreg2 using table1.tex, tex append
xtreg Ahousing_tr Ai Astir, re vce(r) 
outreg2 using table1.tex, tex append
xtreg Ahousing_tr Aell Astir, re vce(r) 
outreg2 using table1.tex, tex append
* NOTE: since Aell=Ai-Astir, replacing Ai with Aell as a regressor makes the
* coefficient on Astir equal the sum _b[Ai]+_b[Astir] from the other regression,
* so this sum can easily be compared to the model prediction of 1


*** alternative regressions with bill_rate instead of stir
xtreg Arisky_tr Ai Abill_rate, re vce(r) 
outreg2 using table2.tex, tex replace
xtreg Arisky_tr Aell Abill_rate, re vce(r) 
outreg2 using table2.tex, tex append
xtreg Aeq_tr Ai Abill_rate, re vce(r) 
outreg2 using table2.tex, tex append
xtreg Aeq_tr Aell Abill_rate, re vce(r) 
outreg2 using table2.tex, tex append
xtreg Ahousing_tr Ai Abill_rate, re vce(r) 
outreg2 using table2.tex, tex append
xtreg Ahousing_tr Aell Abill_rate, re vce(r) 
outreg2 using table2.tex, tex append

* => not much different


*** with inflation and real growth entered sepatately, as a test of log utility
xtreg Arisky_tr Agrowth Api Astir, re vce(r) 
xtreg Aeq_tr Agrowth Api Astir, re vce(r) 
xtreg Ahousing_tr Agrowth Api Astir, re vce(r) 

* => inflation and real growth coefficients are not significantly different 
*    from another, so we conclude log utility assumption is acceptable


*** check FE vs RE model
quietly xtreg Arisky_tr Ai Astir, re 
estimates store riskyreg_re
quietly xtreg Arisky_tr Ai Astir, fe 
estimates store riskyreg_fe
hausman riskyreg_fe riskyreg_re

quietly xtreg Aeq_tr Ai Astir, re 
estimates store eqreg_re
quietly xtreg Aeq_tr Ai Astir, fe 
estimates store eqreg_fe
hausman eqreg_fe eqreg_re

quietly xtreg Ahousing_tr Ai Astir, re 
estimates store housingreg_re
quietly xtreg Ahousing_tr Ai Astir, fe 
estimates store housingreg_fe
hausman housingreg_fe housingreg_re

* => all support RE

